@@ -7,6 +7,7 @@ import time
 from datetime import datetime
 from slugify import slugify
 import glob
+import shutil
 
 import chardet
 
@@ -29,6 +30,8 @@ clean_up = [
     ".dvi",
 ]
 
+clean_path = ["minted"]
+
 
 def predict_encoding(file_path: str, n_lines: int = 20) -> str:
     """Predict a file's encoding using chardet
@@ -143,12 +146,22 @@ def clean_aux(paths: list) -> None:
     Args:
         paths (list): _description_
     """
+    print(paths)
     for path in paths:
         try:
+            print(path)
+
             for file in os.listdir(path):
-                ext = os.path.splitext((file))[1]
-                if ext in clean_up:
-                    os.remove(os.path.join(path, file))
+                if True in [term in file for term in clean_path]:
+                    print(file)
+                    if os.path.isdir(file):
+                        shutil.rmtree(file, ignore_errors=True)
+                else:
+
+                    ext = os.path.splitext((file))[1]
+                    if ext in clean_up:
+                        os.remove(os.path.join(path, file))
+
         except:
             pass
 
